@@ -80,7 +80,7 @@ class ScpiNumber(ScpiTypeBase):
             return f'{self._value:d}{(" " + self._unit) if self._unit is not None else ""}'
         elif type(self._value) == float:
             # Compose into NR2/3 representation
-            return f'{self._value:e}{(" " + self._unit) if self._unit is not None else ""}'
+            return f'{self._value:.15g}{(" " + self._unit) if self._unit is not None else ""}'
         else:
             raise TypeError
 
